**********************************************************************
* Katrin Auspurg & Thomas Hinz (in cooperation with Carsten Sauer)
* Accompanying material for: Factorial Survey Experiments.
* SAGE,  Series: Quantitative Applications in the Social Sciences No. 175, 
* Thousand Oaks, CA: SAGE
* 
* // 1 SETUP OF VIGNETTE UNIVERSE AND RANDOM SAMPLE OF VIGNETTES
*************************************************************************


*****************************************
// #1 GENERATION OF VIGNETTE UNIVERSE     
*****************************************

** Generate variables for the single dimensions 

range x1 1 2 2 		// sex (2 levels)
range x2 1 8 8  	// age (8 levels)
range x3 1 3 3 		// degree (3 levels)
range x4 1 6 6 		// children (6 levels)
range x5 1 10 10 	// job (10 levels)
range x6 1 2 2 		// experience (2 levels)
range x7 1 2 2 		// tenure (2 levels)
range x8 1 10 10 	// income (10 levels)

** Now generate a rectangular dataset

fillin x1 x2 x3 x4 x5 x6 x7 x8
drop _fillin

** Drop lines with missings

foreach var of varlist  x1-x8 {
drop if `var' == .
}

** Check if the number of cases is correct: 
* 2*8*3*6*10*2*2*10 = 115200

fre x1

** the correlations among the dimensions should be zero: 

corr x1 - x8 

** and all levels should appear with the same frequency: 

tab1 x1 - x8 
fre x1 - x8 			// alternative command

// To put it in terms of experimental designs, 
// in the vignette universe the dimensions are completely "orthogonal" (uncorrelated) 
// and "balanced" (all levels appear with the same frequency).
// One can also say, the design has a maximum of statistical efficiency 
// (maximal independent variation and variance of all dimensions). 
// These are all desirable features of experimental designs! 


save universe_1, replace 

*****************************************
// #2 DELETION OF IMPLAUSIBLE CASES 
*****************************************

** See earnignsexample.doc for more information on implausible cases 

drop if x6 == 1  & x7 == 2 
drop if x5 == 8  & x3 == 1
drop if x5 == 10 & x3 < 3
drop if x5 == 1  & x8 > 6 
drop if (x5 == 2 | x5 == 3)  & x8 > 7  
drop if (x5 > 3 & x5 < 7) & x8 > 8 
drop if x5 == 8  & x8 < 3 
drop if x5 > 8 & x8 < 5

** Save the reduced vignette universe: 

save universe_2, replace 

*****************************************
// #3 DRAWING A RANDOM SAMPLE 
*****************************************

* To make the random sampling replicable, indicate a seed number for the  
* algorithm used by Stata. Otherwise, Stata will use the computer time clock. 

set seed 0813 // in this example, 0813 is defined as the seed number
sample 120, count  // draws a random sample of N = 120 vignettes


* Save your random vignette sample: 

save random_sample120, replace 

*****************************************
// #4 ALLOCATION OF VIGNETTES TO DECKS
*****************************************

* If you want the respondents to evaluate 10 vignettes 
* you have to create 120/100 = 12 decks

** To create these decks, you can proceed like this: 
* divide the sample into 12 equal-sized fractions:

gen nr = _n // running number for all vignettes
xtile deck = nr, nquantiles(12) //splits the sample into 12 quantiles
lab var deck "vignette deck"
drop nr

* This procedure leads to a random allocation of vignettes, since the vignettes 
* were already randomly drawn from the universe and hence 
* in a random order.

** Generate a variable indicating the serial position of each vignette 
* within the deck: 

bysort deck: gen vignr = _n
lab var vignr "position of vignette within deck"

** Move all identifiers to the first columns of the data set: 

order deck vignr, first


** Check again the statistical efficiency of the vignette sample 
* and the single decks: 

corr x1 - x8 
fre  x1 - x8 

bysort deck: corr x1 - x8
bysort deck: fre x1 - x8

* You might also check two-way interactions: 

unab vars : x1-x8
local nvar : word count `vars'
forval i = 1/`nvar' {
  forval j = 1/`=`i'-1' {
    local x : word `i' of `vars'
    local y : word `j' of `vars'
    generate `y'X`x' = `y' * `x'
  }
}
corr x1 - x7Xx8
drop x1Xx2 - x7Xx8

*****************************************
// # 5 SAVE DATA
*****************************************

save random120, replace 

