**********************************************************************
* Katrin Auspurg & Thomas Hinz (in cooperation with Carsten Sauer)
* Accompanying material for: Factorial Survey Experiments.
* SAGE,  Series: Quantitative Applications in the Social Sciences No. 175, 
* Thousand Oaks, CA: SAGE
* 
* // 4 RANDOM VIGNETTE ORDERS PER RESPONDENT, FURTHER DATA MANAGMENT
*************************************************************************

// Often it is recommendable to use respondent specific vignette orders 
// to prevent order or carry over effects (see Chapter 4) 


*****************************************
// #1: LOAD DATA AND DUPLICATE THEM 
*****************************************

use vignettetexts_1, clear


// duplicate your dataset so that you have as many questinnaire versions
// as there are possible respondents

expandcl 5, generate(superdeck) cluster(deck)
lab var superdeck "superdeck" 
lab var deck deck
order superdeck deck vignr


// In this example we quintuple data so that each deck occurs five times.  
// The cluster option specifies the variable to 
// be used to define a new variable (superdeck) which is a running number 
// within each deck 

* random order of vignettes within the decks

bys superdeck: gen random = runiform()
sort superdeck random
bys superdeck: replace vignr = _n
list in 1 / 100
corr vignr id_ vignr
drop random


save vignettes_expanded_long, replace 

// check again your design   

fre sex - income
corr sex - income


*****************************************
// #2: RANDOM ORDER, WIDE FORMAT 
*****************************************


// Reshape your data to a wide format for their further use 
// in PAPI or CASI questionnaires and for generating random orders of decks. 

reshape wide id_vignette sex - income vigA vigB vigC, i(superdeck) j(vignr)

// Create a variable that identifies blocks containing all 12 decks the represent the whole sample
// only once; this helps to create a more balanced design
// (the nth block will only be used if respondents have completely rated 
// the n-1th block; 
// therewith it is ensured that all decks get rated with about the same frequency.) 

sort deck superdeck
bysort deck: gen block = _n
fre block

bysort block: gen random_order = runiform()  
* one possiblity to generate a random order of decks within each block
sort block random_order
gen id_quest = _n
drop random_order
drop superdeck
order id_quest deck
lab var id_quest "ID of questionnaire"
lab var block "block containing one complete vignette sample"

*****************************************
// #3: SAVE AND EXPORT DATA
*****************************************

// save as .dta and .csv
 
save vignettes_expanded_wide
export excel using vignettes_expanded_wide, replace

*****************************************
// #4: KEEP SETUP DATA 
*****************************************

drop vig*  // you might only keep numerical codes in your setup data
reshape long id_vignette sex age degree children job experience tenure income, ///
i(id_quest) j(vignr)

save setup, replace 

***!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!***
* Now you have to save these data as setup data - these are now the data that will be used for data analyses.
* The variables id_quest and vignr will be needed to merge the setup data with information on the vignettes 
* with the respondents' data containing the vignette evaluations etc. 
* There are also other ways to achieve random orders of vignettes per respondent. 
* You can follow your own way, but please make sure that you are certainly able to identify the vignettes 
* all respondents rated in the correct order and to merge the setup data with the response data. 






